@@ -501,7 +501,7 @@ class String(Trafaret):
 
     def _check_val(self, value):
         if not isinstance(value, str_types):
-            self._failure("value is not string")
+            self._failure("value is not a string")
         if not self.allow_blank and len(value) is 0:
             self._failure("blank value is not allowed")
         if self.regex is not None:
@@ -551,7 +551,7 @@ class Email(String):
                     pass
                 else:
                     return super(Email, self)._check_val('@'.join(parts))
-        self._failure('value is not email')
+        self._failure('value is not a valid email address')
 
     def __repr__(self):
         return '<Email>'
@@ -745,6 +745,10 @@ class Key(object):
         self.optional = True
         self.default = None
 
+    def __repr__(self):
+        return '<%s "%s"%s>' % (self.__class__.__name__, self.name,
+           ' to "%s"' % self.to_name if getattr(self, 'to_name', False) else '')
+
 
 class Dict(Trafaret):
 
@@ -820,6 +824,7 @@ class Dict(Trafaret):
         for key in self.keys:
             if key.name in args or '*' in args:
                 key.make_optional()
+        return self
 
     def _check_val(self, value):
         if not isinstance(value, dict):
